@@ -991,7 +991,6 @@ def _textbutton(label, clicked=None, style=None, text_style=None, substitute=Tru
     rv = renpy.display.behavior.Button(style=style, clicked=clicked, **button_kwargs)
     text = renpy.text.text.Text(label, style=text_style, substitute=substitute, scope=scope, **text_kwargs)
     rv.add(text)
-    rv._main = text
     rv._composite_parts = [ text ]
     return rv
 
@@ -1112,7 +1111,9 @@ def viewport_common(vpfunc, _spacing_to_side, scrollbars=None, **properties):
         from renpy.sl2.slproperties import position_property_names
 
         for k, v in core_properties.items():
-            if k in position_property_names:
+            if (renpy.config.compat_viewport_minimum) and (k in { "minimum", "xminimum", "yminimum" }):
+                viewport_properties[k] = v
+            elif k in position_property_names:
                 side_properties[k] = v
             elif _spacing_to_side and (k == "spacing"):
                 side_properties[k] = v
